# dujournal

> 期刊常用的一些网站

+ PubMed
    - [PubMed Journal](https://www.ncbi.nlm.nih.gov/nlmcatalog/journals/)
    - [PubMed Mesh](https://www.ncbi.nlm.nih.gov/mesh/)
+ JCR
    - [JCR](https://jcr.clarivate.com/JCRJournalHomeAction.action) # 需要账号有订阅
    - [JCR-ESI](https://esi.help.clarivate.com/Content/journal-list.htm)
+ ZKY
    - 中科院分区
    - [中科院-预警期刊](https://earlywarning.fenqubiao.com/#/)
+ [SJR](https://www.scimagojr.com/journalsearch.php)
